﻿using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;

namespace AvatarWrapper
{
    /// <summary>
    /// This is the main type for your game
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;

        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            graphics.PreferredBackBufferWidth = 1280;
            graphics.PreferredBackBufferHeight = 720;
            Content.RootDirectory = "Content";
            Components.Add(new GamerServicesComponent(this));
        }

        /// <summary>
        /// Allows the game to perform any initialization it needs to before starting to run.
        /// This is where it can query for any required services and load any non-graphic
        /// related content.  Calling base.Initialize will enumerate through any components
        /// and initialize them as well.
        /// </summary>
        protected override void Initialize()
        {
            // TODO: Add your initialization logic here
            base.Initialize();
        }

        List<Avatar> avatars = new List<Avatar>();

        /// <summary>
        /// LoadContent will be called once per game and is the place to load
        /// all of your content.
        /// </summary>
        protected override void LoadContent()
        {
            // Create a new SpriteBatch, which can be used to draw textures.
            spriteBatch = new SpriteBatch(GraphicsDevice);

            Model skinnedModel = Content.Load<Model>("testanim1");

            //initializes the Avatar component
            Avatar.Initialize(GraphicsDevice, Content);

            //create a bunch of new avatars
            //it may take several seconds on the Xbox to load them all
            Random rand =new Random();
            for (int i = 0; i < 10; i++)
            {
                Avatar a = new Avatar(AvatarDescription.CreateRandom());

                //get a random preset animation
                int r = rand.Next(0,30);
                AvatarAnimationPreset preset = new AvatarAnimationPreset();
                preset += r;

                //start the animation
                a.StartAnimation(preset, true);
                //alternatively, uncomment this line for a user-defined animation
                //a.StartAnimation(skinnedModel, "Take 001", true);

                a.Position = new Vector3(rand.Next(-10,10), 0, rand.Next(-20,30));

                a.View = Matrix.CreateLookAt(new Vector3(0, 4, -20), Vector3.Zero, Vector3.Up);

                avatars.Add(a);
            }

        }

        /// <summary>
        /// UnloadContent will be called once per game and is the place to unload
        /// all content.
        /// </summary>
        protected override void UnloadContent()
        {
            // TODO: Unload any non ContentManager content here
        }

        /// <summary>
        /// Allows the game to run logic such as updating the world,
        /// checking for collisions, gathering input, and playing audio.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Update(GameTime gameTime)
        {
            // Allows the game to exit
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            GamePadState gamePad = GamePad.GetState(PlayerIndex.One);

            //update all of the avatars
            foreach (Avatar a in avatars)
            {
                a.Update(gameTime);
                
                //show off the rotations
                a.Rotation.Y += 0.01f;
            }

            // TODO: Add your update logic here

            base.Update(gameTime);
        }

        /// <summary>
        /// This is called when the game should draw itself.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Draw(GameTime gameTime)
        {
            GraphicsDevice.Clear(Color.CornflowerBlue);

            // TODO: Add your drawing code here

            //draw all of the avatars
            foreach (Avatar a in avatars)
            {
                a.Draw();
            }

            base.Draw(gameTime);
        }
    }
}
